# NOTE: This is a generated file. Found a bug? Fix it in
# `scripts/generate_html_component`.
from ...component import Component


class Base(Component):
    def __init__(self, *slots, href=None, target=None):
        self.attr({"href": href, "target": target})

        super().__init__(*slots)

    def render(self):
        return Component(tag_name="base").proxy(self).render()
