from .template import Template  # noqa
from .slot import Slot  # noqa
from .summary import Summary  # noqa
from .menu import Menu  # noqa
from .dialog import Dialog  # noqa
from .details import Details  # noqa
from .textarea import Textarea  # noqa
from .select import Select  # noqa
from .progress import Progress  # noqa
from .output import Output  # noqa
from .option import Option  # noqa
from .optgroup import Optgroup  # noqa
from .meter import Meter  # noqa
from .legend import Legend  # noqa
from .label import Label  # noqa
from .input import Input  # noqa
from .form import Form  # noqa
from .fieldset import Fieldset  # noqa
from .datalist import Datalist  # noqa
from .button import Button  # noqa
from .tr import Tr  # noqa
from .thead import Thead  # noqa
from .th import Th  # noqa
from .tfoot import Tfoot  # noqa
from .td import Td  # noqa
from .tbody import Tbody  # noqa
from .table import Table  # noqa
from .colgroup import Colgroup  # noqa
from .col import Col  # noqa
from .caption import Caption  # noqa
from .ins import Ins  # noqa
from .del_ import Del  # noqa
from .script import Script  # noqa
from .noscript import Noscript  # noqa
from .canvas import Canvas  # noqa
from .source import Source  # noqa
from .picture import Picture  # noqa
from .param import Param  # noqa
from .object import Object  # noqa
from .iframe import Iframe  # noqa
from .embed import Embed  # noqa
from .video import Video  # noqa
from .track import Track  # noqa
from .map import Map  # noqa
from .img import Img  # noqa
from .audio import Audio  # noqa
from .area import Area  # noqa
from .wbr import Wbr  # noqa
from .var import Var  # noqa
from .u import U  # noqa
from .time import Time  # noqa
from .sup import Sup  # noqa
from .sub import Sub  # noqa
from .strong import Strong  # noqa
from .span import Span  # noqa
from .small import Small  # noqa
from .samp import Samp  # noqa
from .s import S  # noqa
from .ruby import Ruby  # noqa
from .rtc import Rtc  # noqa
from .rt import Rt  # noqa
from .rp import Rp  # noqa
from .rb import Rb  # noqa
from .q import Q  # noqa
from .mark import Mark  # noqa
from .kbd import Kbd  # noqa
from .i import I  # noqa
from .em import Em  # noqa
from .dfn import Dfn  # noqa
from .data import Data  # noqa
from .code import Code  # noqa
from .cite import Cite  # noqa
from .br import Br  # noqa
from .bdo import Bdo  # noqa
from .bdi import Bdi  # noqa
from .b import B  # noqa
from .abbr import Abbr  # noqa
from .a import A  # noqa
from .ul import Ul  # noqa
from .pre import Pre  # noqa
from .p import P  # noqa
from .ol import Ol  # noqa
from .li import Li  # noqa
from .hr import Hr  # noqa
from .figure import Figure  # noqa
from .figcaption import Figcaption  # noqa
from .dt import Dt  # noqa
from .dl import Dl  # noqa
from .div import Div  # noqa
from .dd import Dd  # noqa
from .blockquote import Blockquote  # noqa
from .section import Section  # noqa
from .nav import Nav  # noqa
from .main import Main  # noqa
from .hgroup import Hgroup  # noqa
from .header import Header  # noqa
from .footer import Footer  # noqa
from .aside import Aside  # noqa
from .article import Article  # noqa
from .address import Address  # noqa
from .body import Body  # noqa
from .title import Title  # noqa
from .style import Style  # noqa
from .meta import Meta  # noqa
from .link import Link  # noqa
from .head import Head  # noqa
from .base import Base  # noqa
from .html import Html  # noqa
